@@ -18,9 +18,13 @@ class BasiConfig(AppConfig):
     def __init__(self, app_name: str, app_module: Optional[ModuleType]) -> None:
         super().__init__(app_name, app_module)
         _init_settings(DEFAULT_NAMESPACE)
-        from .django._persistent_models import _patch
-        _patch()
+        from .django._persistent_models import _patch_base
+        _patch_base()
+
+    def import_models(self) -> None:
+        from .django._persistent_models import _patch_polymorphic
+        _patch_polymorphic()
+        return super().import_models()
 
     def ready(self) -> None:
-        
         autodiscover_app_tasks(get_current_app())
\ No newline at end of file
